@@ -180,8 +180,8 @@ class Chat(CompanyAssetModel):
 
     @property
     def is_first_message(self) -> bool:
-        """Check if the first message in the chat is a non-central message"""
-        return len(self.real_messages) < 2
+        """This is actually checking if it's the first time the user is writting to us based on the fact that all messages are incoming (still no answer from us)"""
+        return (all(message.is_incoming_message for message in self.real_messages))
 
     @property
     def real_messages(self) -> List[ChattyMessage]:
