@@ -2,6 +2,7 @@ from pydantic import Field, ConfigDict, field_validator, SecretStr, model_valida
 from typing import Optional, List, Dict
 from ..base_models import ChattyAssetModel
 from letschatty.models.channels.channel import WhatsAppClientInfo
+from letschatty.models.utils.types import StrObjectId
 
 class EmpresaModel(ChattyAssetModel):
     name: str = Field(description="The name of the company")
@@ -17,7 +18,7 @@ class EmpresaModel(ChattyAssetModel):
     active: Optional[bool] = Field(default = True)
     friendly_aliases: list[str] = Field(description="The friendly aliases of the company used for the enviamewhats.app links", default_factory=lambda: [])
     terms_of_service_agreement: Optional[bool] = Field(default = False)
-    display_phone_number: Optional[str] = Field(description="The display phone number user's write to", default = None, alias="display_phone_number")
+    display_phone_number: str = Field(description="The display phone number user's write to", default = "33333333333333", alias="display_phone_number")
     phone_number_id: Optional[str] = Field(description="The phone number id of the company", alias="phone_number_id", default = None)
     business_account_id: Optional[str] = Field(description="The WABA - WhatsApp Business Account id of the company", default = None, alias="bussiness_account_id")
     photo_url: str = Field(default = "")
@@ -28,11 +29,17 @@ class EmpresaModel(ChattyAssetModel):
     dataset_id: Optional[str] = Field(default = None, description="To notify events to Meta Conversions API")
     hammer_credentials: Optional[Dict[str,str]] = Field(default = None, description="Only usef for hammer propiedades real state agencies")
     continuous_conversation_template_name: Optional[str] = Field(default = None, description="The name of the continuous conversation template")
+    default_follow_up_strategy_id: Optional[StrObjectId] = Field(default = None, description="The id of the default follow up strategy")
 
     model_config = ConfigDict(
         populate_by_name=True
     )
 
+    @field_validator("display_phone_number", mode="before")
+    def validate_display_phone_number(cls, v):
+        if v is None:
+            return "33333333333333"
+        return v
 
     @model_validator(mode="before")
     def validate_frozen_name(cls, data: Dict) -> Dict:
@@ -44,6 +51,12 @@ class EmpresaModel(ChattyAssetModel):
     def validate_name(cls, v):
         return v
 
+    @property
+    def default_follow_up_strategy_id_value(self) -> StrObjectId:
+        if self.default_follow_up_strategy_id is None:
+            raise ValueError(f"default_follow_up_strategy_id is not set for company {self.name}")
+        return self.default_follow_up_strategy_id
+
     @property
     def active_continuous_conversation_template_name(self) -> str:
         if not self.continuous_conversation_template_name:
@@ -101,4 +114,4 @@ class EmpresaModel(ChattyAssetModel):
             self.display_phone_number_value
             return True
         except ValueError:
-            return False
+            return False
\ No newline at end of file
