@@ -1,7 +1,7 @@
 from .base.message_base import Message
 from ...utils.types.message_types import MessageType
-
+from .schema import ChattyContentButton
 
 class ButtonMessage(Message):
-   #TODO: Implementar
-   pass
\ No newline at end of file
+    type: MessageType = MessageType.BUTTON
+    content: ChattyContentButton
\ No newline at end of file
