@@ -20,4 +20,7 @@ class ChattyContentCentral(BaseModel):
 
     def model_dump(self, *args, **kwargs):
         kwargs['exclude_unset'] = True
-        return super().model_dump(*args, **kwargs)
\ No newline at end of file
+        return super().model_dump(*args, **kwargs)
+
+    def get_body_or_caption(self) -> str:
+        return self.body
\ No newline at end of file
