@@ -6,6 +6,7 @@ from ...models.company.empresa import EmpresaModel
 from ...models.utils.types import StrObjectId
 from bson import ObjectId
 from datetime import datetime
+from zoneinfo import ZoneInfo
 import logging
 logger = logging.getLogger("ChattyAssetBaseContainer")
 
@@ -92,6 +93,7 @@ class ChattyAssetBaseContainer(Generic[T, P], ABC):
                 f"Item with id {item_id} not found in {self.__class__.__name__}."
             )
         item = self.items.pop(item_id)
+        item.deleted_at = datetime.now(ZoneInfo("UTC"))
         return item
 
     def get_by_id(self, item_id: str) -> T:
