@@ -141,12 +141,13 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
             logger.debug(f"{self.__class__.__name__} deleting item {id}")
             deleted_item = super().delete(id)
             self.delete_preview(id)
-            self.update_previews_thread()
             execution_context.set_event_time(datetime.now(ZoneInfo("UTC")))
             self.collection.delete(id, deletion_type)
             return deleted_item
         except NotFoundError as e:
             self.collection.delete(id, deletion_type)
+            self.delete_preview(id)
+            self.update_previews_thread()
             execution_context.set_event_time(datetime.now(ZoneInfo("UTC")))
             return self.collection.get_by_id(id)
 
@@ -199,7 +200,7 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
             self.update_previews_cache()
         previews = super().get_all_previews(company_id=company_id)
         self.preview_last_accessed_at_cache = datetime.now(ZoneInfo("UTC"))
-        previews= [json.loads(preview.model_dump_json()) for preview in previews]
+        previews= [json.loads(preview.model_dump_json()) for preview in previews if preview.deleted_at is None]
         logger.debug(f"Previews: {previews}")
         return previews
 
@@ -288,8 +289,8 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
     def load_from_db(self, company_id: Optional[StrObjectId]):
         """Pass company_id=None to load all items from the database."""
         logger.debug(f"{self.__class__.__name__} loading items from collection")
-        self.items = {item.id: item for item in self.collection.get_docs(query={}, company_id=company_id)}
-        # self.items = {item.id: item for item in self.collection.get_docs(query={"deleted_at": None}, company_id=company_id)}
+        # self.items = {item.id: item for item in self.collection.get_docs(query={}, company_id=company_id)}
+        self.items = {item.id: item for item in self.collection.get_docs(query={"deleted_at": None}, company_id=company_id)}
 
     def restore(self, id: str, execution_context: ExecutionContext) -> T:
         logger.debug(f"{self.__class__.__name__} restoring item {id} with execution context {execution_context}")
